Module binder

Module binder 

This mod provides various types and utilities for code generation.

Structs

BinderContext
Context data to invoke bind function.

Traits

Binder
A binder is the specific-language code generator of solidity abi.
BinderError
The trait that the error returned by binder traits must implement.
ConstructorBinder
A trait object returns by bind_constructor function.
ContractBinder
A trait object returns by prepare function.
EventBinder
A trait object returns by bind_event function.
FunctionBinder
A trait object returns by bind_function function.
TupleBinder
A trait object returns by bind_tuple function.

Functions

bind
Invoke code generation with context data.