This mod provides various types and utilities for code generation.
Structs
- Binder
Context - Context data to invoke
bindfunction.
Traits
- Binder
- A binder is the specific-language code generator of solidity abi.
- Binder
Error - The trait that the error returned by binder traits must implement.
- Constructor
Binder - A trait object returns by
bind_constructorfunction. - Contract
Binder - A trait object returns by
preparefunction. - Event
Binder - A trait object returns by
bind_eventfunction. - Function
Binder - A trait object returns by
bind_functionfunction. - Tuple
Binder - A trait object returns by
bind_tuplefunction.
Functions
- bind
- Invoke code generation with
context data.