pub struct BinderTypeMapping { /* private fields */ }Expand description
The context to map solidity type to target strong type language.
you can read mapping data from any serde compatibable data formats.
Implementations
Sourceimpl BinderTypeMapping
impl BinderTypeMapping
Sourcepub fn abi_type_mapping(&mut self, abi_type: &Type) -> Option<&str>
pub fn abi_type_mapping(&mut self, abi_type: &Type) -> Option<&str>
Mapping abi type to target language type.
Sourcepub fn rt_type_mapping(&self, rt_type: &str) -> Option<&str>
pub fn rt_type_mapping(&self, rt_type: &str) -> Option<&str>
Mapping binder-specific runtime type into target language type.
runtime Type is the runtime type of the target web3 framework that must be known to generate code.